#pragma semicolon 1

#include <sourcemod>
#include <sdktools>
#include <vip_core>

public Plugin:myinfo =
{
	name = "[VIP] Ban",
	author = "R1KO (skype: vova.andrienko1)",
	version = "1.0.2"
};

#define VIP_BAN				"Ban"

public VIP_OnVIPLoaded()
{
	VIP_RegisterFeature(VIP_BAN, BOOL, SELECTABLE, OnSelectItem);
}

new Handle:g_hReasonsMenu,
	Handle:g_hTimesMenu,
	g_iCvar_AdminImmunityMode,
	bool:g_bCvar_VIPImmunityMode;

public OnPluginStart()
{
	LoadTranslations("common.phrases");
	LoadTranslations("basebans.phrases");

	g_hReasonsMenu = CreateMenu(Handler_ReasonsMenu, MenuAction_Select|MenuAction_Cancel);
	SetMenuExitBackButton(g_hReasonsMenu, true);
	SetMenuTitle(g_hReasonsMenu, ":\n \n");
	
	g_hTimesMenu = CreateMenu(Handler_TimesMenu, MenuAction_Select|MenuAction_Cancel);
	SetMenuExitBackButton(g_hTimesMenu, true);
	SetMenuTitle(g_hTimesMenu, ":\n \n");
}

public OnMapStart()
{
	RemoveAllMenuItems(g_hReasonsMenu);
	RemoveAllMenuItems(g_hTimesMenu);
	
	decl String:sBuffer[256], Handle:hKeyValues;

	hKeyValues = CreateKeyValues("Ban");
	BuildPath(Path_SM, sBuffer, 256, "data/vip/modules/ban.ini");

	if (FileToKeyValues(hKeyValues, sBuffer) == false)
	{
		SetFailState("    \"%s\"", sBuffer);
	}
	
	KvRewind(hKeyValues);
	
	g_iCvar_AdminImmunityMode = KvGetNum(hKeyValues, "vip_ban_admin_immunity");
	g_bCvar_VIPImmunityMode = bool:KvGetNum(hKeyValues, "vip_ban_vip_immunity");
	
	KeyValuesToMenu(hKeyValues, "Reasons", g_hReasonsMenu);
	KeyValuesToMenu(hKeyValues, "Times", g_hTimesMenu);
	
	CloseHandle(hKeyValues);
}

KeyValuesToMenu(&Handle:hKeyValues, const String:sKey[], &Handle:hMenu)
{
	KvRewind(hKeyValues);
	if (KvJumpToKey(hKeyValues, sKey) && KvGotoFirstSubKey(hKeyValues, false))
	{
		decl String:sItem[64], String:sItemInfo[64];
		do
		{
			KvGetSectionName(hKeyValues, sItem, sizeof(sItem));
			KvGetString(hKeyValues, NULL_STRING, sItemInfo, sizeof(sItemInfo));
			AddMenuItem(hMenu, sItemInfo, sItem);
			LogMessage("AddMenuItem %s (%s) -> %s", sItem, sItemInfo, sKey);
		}
		while (KvGotoNextKey(hKeyValues, false));
	}
}

public bool:OnSelectItem(iClient, const String:sFeatureName[])
{
	DisplayMenu(CreatePlayersMenu(iClient), iClient, MENU_TIME_FOREVER);
	return false;
}

Handle:CreatePlayersMenu(iClient)
{
	decl String:sUserID[16], String:sName[64], Handle:hMenu, i, AdminId:AID;
	hMenu = CreateMenu(PlayersMenu_Handler);
	SetMenuExitBackButton(hMenu, true);
	SetMenuTitle(hMenu, "%T:\n \n", "Ban player", iClient);
	
	sUserID[0] = 0;
	for(i = 1; i <= MaxClients; ++i)
	{
		if(IsClientInGame(i))
		{
			if(g_bCvar_VIPImmunityMode && VIP_IsClientVIP(i))
			{
				continue;
			}
			
			AID = GetUserAdmin(i);
			if(g_iCvar_AdminImmunityMode == 0 && AID != INVALID_ADMIN_ID)
			{
				continue;
			}

			if(g_iCvar_AdminImmunityMode > 0 && GetAdminImmunityLevel(AID) >= g_iCvar_AdminImmunityMode)
			{
				continue;
			}
			
			GetClientName(i, sName, sizeof(sName));
			IntToString(GetClientUserId(i), sUserID, sizeof(sUserID));
			AddMenuItem(hMenu, sUserID, sName);
		}
	}

	if(sUserID[0] == 0)
	{
		FormatEx(sName, sizeof(sName), "%T", "No matching clients", iClient);
		AddMenuItem(hMenu, "", sName, ITEMDRAW_DISABLED);
	}

	return hMenu;
}

public PlayersMenu_Handler(Handle:hMenu, MenuAction:action, iClient, Item)
{
	switch(action)
	{
		case MenuAction_End: CloseHandle(hMenu);
		case MenuAction_Cancel:
		{
			if(Item == MenuCancel_ExitBack)
			{
				VIP_SendClientVIPMenu(iClient);
			}
		}
		case MenuAction_Select:
		{
			decl String:sUserID[16], UserID;
			GetMenuItem(hMenu, Item, sUserID, sizeof(sUserID));
			UserID = StringToInt(sUserID);
			if(GetClientOfUserId(UserID))
			{
				SetTrieValue(VIP_GetVIPClientTrie(iClient), "BanTarget", UserID);
				DisplayMenu(g_hTimesMenu, iClient, MENU_TIME_FOREVER);
				LogMessage("Show g_hTimesMenu %N (%i)", iClient, iClient);
			//	DisplayMenu(g_hReasonsMenu, iClient, MENU_TIME_FOREVER);
			}
			else
			{
				PrintToChat(iClient, "[SM] %t", "Player no longer available");
			}
		}
	}
}

public Handler_TimesMenu(Handle:hMenu, MenuAction:action, iClient, Item)
{
	switch(action)
	{
		case MenuAction_Cancel:
		{
			if(Item == MenuCancel_ExitBack)
			{
				DisplayMenu(CreatePlayersMenu(iClient), iClient, MENU_TIME_FOREVER);
			}
		}
		case MenuAction_Select:
		{
			decl String:sTime[32], iTarget;
			GetMenuItem(hMenu, Item, sTime, sizeof(sTime));
			if(GetTrieValue(VIP_GetVIPClientTrie(iClient), "BanTarget", iTarget))
			{
				iTarget = GetClientOfUserId(iTarget);
				if(iTarget && IsClientInGame(iTarget))
				{
					SetTrieValue(VIP_GetVIPClientTrie(iClient), "BanTime", StringToInt(sTime));
					DisplayMenu(g_hReasonsMenu, iClient, MENU_TIME_FOREVER);
				}
				else
				{
					PrintToChat(iTarget, "[SM] %t", "Player no longer available");
				}
			}
		}
	}
}

public Handler_ReasonsMenu(Handle:hMenu, MenuAction:action, iClient, Item)
{
	switch(action)
	{
		case MenuAction_Cancel:
		{
			if(Item == MenuCancel_ExitBack)
			{
				DisplayMenu(CreatePlayersMenu(iClient), iClient, MENU_TIME_FOREVER);
			}
		}
		case MenuAction_Select:
		{
			decl String:sReason[128], iTarget;
			GetMenuItem(hMenu, Item, sReason, sizeof(sReason));
			if(GetTrieValue(VIP_GetVIPClientTrie(iClient), "BanTarget", iTarget))
			{
				iTarget = GetClientOfUserId(iTarget);
				if(iTarget && IsClientInGame(iTarget))
				{
					decl String:sName[MAX_NAME_LENGTH], iBanTime;
					GetTrieValue(VIP_GetVIPClientTrie(iClient), "BanTime", iBanTime);
					GetClientName(iTarget, sName, sizeof(sName));
					if (iBanTime)
					{
						VIP_PrintToChatAll("\x01VIP- \x04%N \x01  \x04%s  \x04%i \x01 (: \x04%s\x01)", iClient, sName, iBanTime, sReason);
					//	ShowActivity(client, "%t", "Banned player reason", sName, iBanTime, sReason);
					}
					else
					{
						VIP_PrintToChatAll("\x01VIP- \x04%N \x01  \x04%s  (: \x04%s\x01)", iClient, sName, sReason);
						// ShowActivity(client, "%t", "Permabanned player reason", sName, iBanTime, sReason);
					}
	
				//	VIP_PrintToChatAll("\x01VIP- \x04%N \x01  \x04%s  \x04%i \x01 (: \x04%s\x01)", iClient, sName, iBanTime, sReason);
				//	VIP_PrintToChatClient(iClient, "\x01%t", "Baned target reason", "_s", sName, sReason);
					LogAction(iClient, iTarget, "VIP- \"%L\"   \"%L\" (: %i, : %s)", iClient, iTarget, iBanTime, sReason);
					//BanClient(iTarget, iBanTime, BANFLAG_AUTO, sReason, sReason, "sm_ban", iClient);
					ServerCommand("sm_ban #%d %d \"%s\"", GetClientUserId(iTarget), iBanTime, sReason);
				}
				else
				{
					PrintToChat(iTarget, "[SM] %t", "Player no longer available");
				}
			}
		}
	}
}
